import { API as ParentAPI } from '../../../bridge';
import type { Region } from '../../../bridge';
import type { ListNatsAccountsResponse, ListNatsCredentialsResponse, ListSnsCredentialsResponse, ListSqsCredentialsResponse, NatsAccount, NatsApiCreateNatsAccountRequest, NatsApiCreateNatsCredentialsRequest, NatsApiDeleteNatsAccountRequest, NatsApiDeleteNatsCredentialsRequest, NatsApiGetNatsAccountRequest, NatsApiGetNatsCredentialsRequest, NatsApiListNatsAccountsRequest, NatsApiListNatsCredentialsRequest, NatsApiUpdateNatsAccountRequest, NatsCredentials, SnsApiActivateSnsRequest, SnsApiCreateSnsCredentialsRequest, SnsApiDeactivateSnsRequest, SnsApiDeleteSnsCredentialsRequest, SnsApiGetSnsCredentialsRequest, SnsApiGetSnsInfoRequest, SnsApiListSnsCredentialsRequest, SnsApiUpdateSnsCredentialsRequest, SnsCredentials, SnsInfo, SqsApiActivateSqsRequest, SqsApiCreateSqsCredentialsRequest, SqsApiDeactivateSqsRequest, SqsApiDeleteSqsCredentialsRequest, SqsApiGetSqsCredentialsRequest, SqsApiGetSqsInfoRequest, SqsApiListSqsCredentialsRequest, SqsApiUpdateSqsCredentialsRequest, SqsCredentials, SqsInfo } from './types.gen';
/**
 * Messaging and Queuing NATS API.
 *
 * This API allows you to manage Scaleway Messaging and Queuing NATS accounts.
 */
export declare class NatsAPI extends ParentAPI {
    /** Lists the available regions of the API. */
    static readonly LOCALITIES: Region[];
    /**
     * Create a NATS account. Create a NATS account associated with a Project.
     *
     * @param request - The request {@link NatsApiCreateNatsAccountRequest}
     * @returns A Promise of NatsAccount
     */
    createNatsAccount: (request?: Readonly<NatsApiCreateNatsAccountRequest>) => Promise<NatsAccount>;
    /**
     * Delete a NATS account. Delete a NATS account, specified by its NATS account
     * ID. Note that deleting a NATS account is irreversible, and any credentials,
     * streams, consumer and stored messages belonging to this NATS account will
     * also be deleted.
     *
     * @param request - The request {@link NatsApiDeleteNatsAccountRequest}
     */
    deleteNatsAccount: (request: Readonly<NatsApiDeleteNatsAccountRequest>) => Promise<void>;
    /**
     * Update the name of a NATS account. Update the name of a NATS account,
     * specified by its NATS account ID.
     *
     * @param request - The request {@link NatsApiUpdateNatsAccountRequest}
     * @returns A Promise of NatsAccount
     */
    updateNatsAccount: (request: Readonly<NatsApiUpdateNatsAccountRequest>) => Promise<NatsAccount>;
    /**
     * Get a NATS account. Retrieve information about an existing NATS account
     * identified by its NATS account ID. Its full details, including name and
     * endpoint, are returned in the response.
     *
     * @param request - The request {@link NatsApiGetNatsAccountRequest}
     * @returns A Promise of NatsAccount
     */
    getNatsAccount: (request: Readonly<NatsApiGetNatsAccountRequest>) => Promise<NatsAccount>;
    protected pageOfListNatsAccounts: (request?: Readonly<NatsApiListNatsAccountsRequest>) => Promise<ListNatsAccountsResponse>;
    /**
     * List NATS accounts. List all NATS accounts in the specified region, for a
     * Scaleway Organization or Project. By default, the NATS accounts returned in
     * the list are ordered by creation date in ascending order, though this can
     * be modified via the `order_by` field.
     *
     * @param request - The request {@link NatsApiListNatsAccountsRequest}
     * @returns A Promise of ListNatsAccountsResponse
     */
    listNatsAccounts: (request?: Readonly<NatsApiListNatsAccountsRequest>) => Promise<ListNatsAccountsResponse> & {
        all: () => Promise<NatsAccount[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<NatsAccount[], void, void>;
    };
    /**
     * Create NATS credentials. Create a set of credentials for a NATS account,
     * specified by its NATS account ID.
     *
     * @param request - The request {@link NatsApiCreateNatsCredentialsRequest}
     * @returns A Promise of NatsCredentials
     */
    createNatsCredentials: (request: Readonly<NatsApiCreateNatsCredentialsRequest>) => Promise<NatsCredentials>;
    /**
     * Delete NATS credentials. Delete a set of credentials, specified by their
     * credentials ID. Deleting credentials is irreversible and cannot be undone.
     * The credentials can no longer be used to access the NATS account, and
     * active connections using this credentials will be closed.
     *
     * @param request - The request {@link NatsApiDeleteNatsCredentialsRequest}
     */
    deleteNatsCredentials: (request: Readonly<NatsApiDeleteNatsCredentialsRequest>) => Promise<void>;
    /**
     * Get NATS credentials. Retrieve an existing set of credentials, identified
     * by the `nats_credentials_id`. The credentials themselves are NOT returned,
     * only their metadata (NATS account ID, credentials name, etc), are returned
     * in the response.
     *
     * @param request - The request {@link NatsApiGetNatsCredentialsRequest}
     * @returns A Promise of NatsCredentials
     */
    getNatsCredentials: (request: Readonly<NatsApiGetNatsCredentialsRequest>) => Promise<NatsCredentials>;
    protected pageOfListNatsCredentials: (request?: Readonly<NatsApiListNatsCredentialsRequest>) => Promise<ListNatsCredentialsResponse>;
    /**
     * List NATS credentials. List existing credentials in the specified NATS
     * account. The response contains only the metadata for the credentials, not
     * the credentials themselves, which are only returned after a **Create
     * Credentials** call.
     *
     * @param request - The request {@link NatsApiListNatsCredentialsRequest}
     * @returns A Promise of ListNatsCredentialsResponse
     */
    listNatsCredentials: (request?: Readonly<NatsApiListNatsCredentialsRequest>) => Promise<ListNatsCredentialsResponse> & {
        all: () => Promise<NatsCredentials[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<NatsCredentials[], void, void>;
    };
}
/**
 * Messaging and Queuing SNS API.
 *
 * This API allows you to manage your Scaleway Messaging and Queuing SNS
 * brokers.
 */
export declare class SnsAPI extends ParentAPI {
    /** Lists the available regions of the API. */
    static readonly LOCALITIES: Region[];
    /**
     * Activate SNS. Activate SNS for the specified Project ID. SNS must be
     * activated before any usage. Activating SNS does not trigger any billing,
     * and you can deactivate at any time.
     *
     * @param request - The request {@link SnsApiActivateSnsRequest}
     * @returns A Promise of SnsInfo
     */
    activateSns: (request?: Readonly<SnsApiActivateSnsRequest>) => Promise<SnsInfo>;
    /**
     * Get SNS info. Retrieve the SNS information of the specified Project ID.
     * Informations include the activation status and the SNS API endpoint URL.
     *
     * @param request - The request {@link SnsApiGetSnsInfoRequest}
     * @returns A Promise of SnsInfo
     */
    getSnsInfo: (request?: Readonly<SnsApiGetSnsInfoRequest>) => Promise<SnsInfo>;
    /**
     * Deactivate SNS. Deactivate SNS for the specified Project ID.You must delete
     * all topics and credentials before this call or you need to set the
     * force_delete parameter.
     *
     * @param request - The request {@link SnsApiDeactivateSnsRequest}
     * @returns A Promise of SnsInfo
     */
    deactivateSns: (request?: Readonly<SnsApiDeactivateSnsRequest>) => Promise<SnsInfo>;
    /**
     * Create SNS credentials. Create a set of credentials for SNS, specified by a
     * Project ID. Credentials give the bearer access to topics, and the level of
     * permissions can be defined granularly.
     *
     * @param request - The request {@link SnsApiCreateSnsCredentialsRequest}
     * @returns A Promise of SnsCredentials
     */
    createSnsCredentials: (request?: Readonly<SnsApiCreateSnsCredentialsRequest>) => Promise<SnsCredentials>;
    /**
     * Delete SNS credentials. Delete a set of SNS credentials, specified by their
     * credentials ID. Deleting credentials is irreversible and cannot be undone.
     * The credentials can then no longer be used to access SNS.
     *
     * @param request - The request {@link SnsApiDeleteSnsCredentialsRequest}
     */
    deleteSnsCredentials: (request: Readonly<SnsApiDeleteSnsCredentialsRequest>) => Promise<void>;
    /**
     * Update SNS credentials. Update a set of SNS credentials. You can update the
     * credentials' name, or their permissions.
     *
     * @param request - The request {@link SnsApiUpdateSnsCredentialsRequest}
     * @returns A Promise of SnsCredentials
     */
    updateSnsCredentials: (request: Readonly<SnsApiUpdateSnsCredentialsRequest>) => Promise<SnsCredentials>;
    /**
     * Get SNS credentials. Retrieve an existing set of credentials, identified by
     * the `credentials_id`. The credentials themselves, as well as their metadata
     * (name, project ID etc), are returned in the response.
     *
     * @param request - The request {@link SnsApiGetSnsCredentialsRequest}
     * @returns A Promise of SnsCredentials
     */
    getSnsCredentials: (request: Readonly<SnsApiGetSnsCredentialsRequest>) => Promise<SnsCredentials>;
    protected pageOfListSnsCredentials: (request?: Readonly<SnsApiListSnsCredentialsRequest>) => Promise<ListSnsCredentialsResponse>;
    /**
     * List SNS credentials. List existing SNS credentials in the specified
     * region. The response contains only the metadata for the credentials, not
     * the credentials themselves.
     *
     * @param request - The request {@link SnsApiListSnsCredentialsRequest}
     * @returns A Promise of ListSnsCredentialsResponse
     */
    listSnsCredentials: (request?: Readonly<SnsApiListSnsCredentialsRequest>) => Promise<ListSnsCredentialsResponse> & {
        all: () => Promise<SnsCredentials[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<SnsCredentials[], void, void>;
    };
}
/**
 * Messaging and Queuing SQS API.
 *
 * This API allows you to manage your Scaleway Messaging and Queuing SQS
 * brokers.
 */
export declare class SqsAPI extends ParentAPI {
    /** Lists the available regions of the API. */
    static readonly LOCALITIES: Region[];
    /**
     * Activate SQS. Activate SQS for the specified Project ID. SQS must be
     * activated before any usage such as creating credentials and queues.
     * Activating SQS does not trigger any billing, and you can deactivate at any
     * time.
     *
     * @param request - The request {@link SqsApiActivateSqsRequest}
     * @returns A Promise of SqsInfo
     */
    activateSqs: (request?: Readonly<SqsApiActivateSqsRequest>) => Promise<SqsInfo>;
    /**
     * Get SQS info. Retrieve the SQS information of the specified Project ID.
     * Informations include the activation status and the SQS API endpoint URL.
     *
     * @param request - The request {@link SqsApiGetSqsInfoRequest}
     * @returns A Promise of SqsInfo
     */
    getSqsInfo: (request?: Readonly<SqsApiGetSqsInfoRequest>) => Promise<SqsInfo>;
    /**
     * Deactivate SQS. Deactivate SQS for the specified Project ID. You must
     * delete all queues and credentials before this call or you need to set the
     * force_delete parameter.
     *
     * @param request - The request {@link SqsApiDeactivateSqsRequest}
     * @returns A Promise of SqsInfo
     */
    deactivateSqs: (request?: Readonly<SqsApiDeactivateSqsRequest>) => Promise<SqsInfo>;
    /**
     * Create SQS credentials. Create a set of credentials for SQS, specified by a
     * Project ID. Credentials give the bearer access to queues, and the level of
     * permissions can be defined granularly.
     *
     * @param request - The request {@link SqsApiCreateSqsCredentialsRequest}
     * @returns A Promise of SqsCredentials
     */
    createSqsCredentials: (request?: Readonly<SqsApiCreateSqsCredentialsRequest>) => Promise<SqsCredentials>;
    /**
     * Delete SQS credentials. Delete a set of SQS credentials, specified by their
     * credentials ID. Deleting credentials is irreversible and cannot be undone.
     * The credentials can then no longer be used to access SQS.
     *
     * @param request - The request {@link SqsApiDeleteSqsCredentialsRequest}
     */
    deleteSqsCredentials: (request: Readonly<SqsApiDeleteSqsCredentialsRequest>) => Promise<void>;
    /**
     * Update SQS credentials. Update a set of SQS credentials. You can update the
     * credentials' name, or their permissions.
     *
     * @param request - The request {@link SqsApiUpdateSqsCredentialsRequest}
     * @returns A Promise of SqsCredentials
     */
    updateSqsCredentials: (request: Readonly<SqsApiUpdateSqsCredentialsRequest>) => Promise<SqsCredentials>;
    /**
     * Get SQS credentials. Retrieve an existing set of credentials, identified by
     * the `credentials_id`. The credentials themselves, as well as their metadata
     * (name, project ID etc), are returned in the response.
     *
     * @param request - The request {@link SqsApiGetSqsCredentialsRequest}
     * @returns A Promise of SqsCredentials
     */
    getSqsCredentials: (request: Readonly<SqsApiGetSqsCredentialsRequest>) => Promise<SqsCredentials>;
    protected pageOfListSqsCredentials: (request?: Readonly<SqsApiListSqsCredentialsRequest>) => Promise<ListSqsCredentialsResponse>;
    /**
     * List SQS credentials. List existing SQS credentials in the specified
     * region. The response contains only the metadata for the credentials, not
     * the credentials themselves.
     *
     * @param request - The request {@link SqsApiListSqsCredentialsRequest}
     * @returns A Promise of ListSqsCredentialsResponse
     */
    listSqsCredentials: (request?: Readonly<SqsApiListSqsCredentialsRequest>) => Promise<ListSqsCredentialsResponse> & {
        all: () => Promise<SqsCredentials[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<SqsCredentials[], void, void>;
    };
}
