"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const json = require("../../../helpers/json.cjs");
const customMarshalling = require("../../../scw/custom-marshalling.cjs");
const marshalling = require("../../../helpers/marshalling.cjs");
const unmarshalJobCircuit = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'JobCircuit' failed as data isn't a dictionary.`
    );
  }
  return {
    percevalCircuit: data.perceval_circuit,
    qiskitCircuit: data.qiskit_circuit
  };
};
const unmarshalApplication = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Application' failed as data isn't a dictionary.`
    );
  }
  return {
    compatiblePlatformIds: data.compatible_platform_ids,
    id: data.id,
    inputTemplate: data.input_template,
    name: data.name,
    type: data.type
  };
};
const unmarshalJob = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Job' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: marshalling.unmarshalDate(data.created_at),
    id: data.id,
    jobDuration: data.job_duration,
    name: data.name,
    progressMessage: data.progress_message,
    resultDistribution: data.result_distribution,
    sessionId: data.session_id,
    startedAt: marshalling.unmarshalDate(data.started_at),
    status: data.status,
    tags: data.tags,
    updatedAt: marshalling.unmarshalDate(data.updated_at)
  };
};
const unmarshalPlatformHardware = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'PlatformHardware' failed as data isn't a dictionary.`
    );
  }
  return {
    gpus: data.gpus,
    gpusNetwork: data.gpus_network,
    name: data.name,
    ram: data.ram,
    vcpus: data.vcpus,
    vram: data.vram
  };
};
const unmarshalPlatform = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Platform' failed as data isn't a dictionary.`
    );
  }
  return {
    availability: data.availability,
    backendName: data.backend_name,
    hardware: data.hardware ? unmarshalPlatformHardware(data.hardware) : void 0,
    id: data.id,
    maxQubitCount: data.max_qubit_count,
    metadata: data.metadata,
    name: data.name,
    pricePerHour: data.price_per_hour ? customMarshalling.unmarshalMoney(data.price_per_hour) : void 0,
    providerName: data.provider_name,
    technology: data.technology,
    type: data.type,
    version: data.version
  };
};
const unmarshalProcess = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Process' failed as data isn't a dictionary.`
    );
  }
  return {
    applicationId: data.application_id,
    attachedSessionIds: data.attached_session_ids,
    createdAt: marshalling.unmarshalDate(data.created_at),
    finishedAt: marshalling.unmarshalDate(data.finished_at),
    id: data.id,
    input: data.input,
    name: data.name,
    platformId: data.platform_id,
    progress: data.progress,
    progressMessage: data.progress_message,
    projectId: data.project_id,
    startedAt: marshalling.unmarshalDate(data.started_at),
    status: data.status,
    tags: data.tags,
    updatedAt: marshalling.unmarshalDate(data.updated_at)
  };
};
const unmarshalSession = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Session' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: marshalling.unmarshalDate(data.created_at),
    deduplicationId: data.deduplication_id,
    finishedJobCount: data.finished_job_count,
    id: data.id,
    maxDuration: data.max_duration,
    maxIdleDuration: data.max_idle_duration,
    name: data.name,
    originId: data.origin_id,
    originType: data.origin_type,
    platformId: data.platform_id,
    progressMessage: data.progress_message,
    projectId: data.project_id,
    startedAt: marshalling.unmarshalDate(data.started_at),
    status: data.status,
    tags: data.tags,
    terminatedAt: marshalling.unmarshalDate(data.terminated_at),
    updatedAt: marshalling.unmarshalDate(data.updated_at),
    waitingJobCount: data.waiting_job_count
  };
};
const unmarshalListApplicationsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListApplicationsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    applications: marshalling.unmarshalArrayOfObject(
      data.applications,
      unmarshalApplication
    ),
    totalCount: data.total_count
  };
};
const unmarshalJobResult = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'JobResult' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: marshalling.unmarshalDate(data.created_at),
    jobId: data.job_id,
    result: data.result,
    url: data.url
  };
};
const unmarshalListJobResultsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListJobResultsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    jobResults: marshalling.unmarshalArrayOfObject(data.job_results, unmarshalJobResult),
    totalCount: data.total_count
  };
};
const unmarshalListJobsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListJobsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    jobs: marshalling.unmarshalArrayOfObject(data.jobs, unmarshalJob),
    totalCount: data.total_count
  };
};
const unmarshalListPlatformsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListPlatformsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    platforms: marshalling.unmarshalArrayOfObject(data.platforms, unmarshalPlatform),
    totalCount: data.total_count
  };
};
const unmarshalProcessResult = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ProcessResult' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: marshalling.unmarshalDate(data.created_at),
    processId: data.process_id,
    result: data.result
  };
};
const unmarshalListProcessResultsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListProcessResultsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    processResults: marshalling.unmarshalArrayOfObject(
      data.process_results,
      unmarshalProcessResult
    ),
    totalCount: data.total_count
  };
};
const unmarshalListProcessesResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListProcessesResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    processes: marshalling.unmarshalArrayOfObject(data.processes, unmarshalProcess),
    totalCount: data.total_count
  };
};
const unmarshalListSessionACLsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListSessionACLsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    acls: data.acls,
    totalCount: data.total_count
  };
};
const unmarshalListSessionsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListSessionsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    sessions: marshalling.unmarshalArrayOfObject(data.sessions, unmarshalSession),
    totalCount: data.total_count
  };
};
const marshalJobCircuit = (request, defaults) => ({
  ...marshalling.resolveOneOf([
    { param: "perceval_circuit", value: request.percevalCircuit },
    { param: "qiskit_circuit", value: request.qiskitCircuit }
  ])
});
const marshalCreateJobRequest = (request, defaults) => ({
  circuit: marshalJobCircuit(request.circuit),
  max_duration: request.maxDuration,
  name: request.name,
  session_id: request.sessionId,
  tags: request.tags
});
const marshalCreateProcessRequest = (request, defaults) => ({
  application_id: request.applicationId,
  input: request.input,
  name: request.name,
  platform_id: request.platformId,
  project_id: request.projectId ?? defaults.defaultProjectId,
  tags: request.tags
});
const marshalCreateSessionRequest = (request, defaults) => ({
  deduplication_id: request.deduplicationId,
  max_duration: request.maxDuration,
  max_idle_duration: request.maxIdleDuration,
  name: request.name,
  platform_id: request.platformId,
  project_id: request.projectId ?? defaults.defaultProjectId,
  tags: request.tags
});
const marshalUpdateJobRequest = (request, defaults) => ({
  name: request.name,
  tags: request.tags
});
const marshalUpdateProcessRequest = (request, defaults) => ({
  name: request.name,
  tags: request.tags
});
const marshalUpdateSessionRequest = (request, defaults) => ({
  max_duration: request.maxDuration,
  max_idle_duration: request.maxIdleDuration,
  name: request.name,
  tags: request.tags
});
exports.marshalCreateJobRequest = marshalCreateJobRequest;
exports.marshalCreateProcessRequest = marshalCreateProcessRequest;
exports.marshalCreateSessionRequest = marshalCreateSessionRequest;
exports.marshalUpdateJobRequest = marshalUpdateJobRequest;
exports.marshalUpdateProcessRequest = marshalUpdateProcessRequest;
exports.marshalUpdateSessionRequest = marshalUpdateSessionRequest;
exports.unmarshalApplication = unmarshalApplication;
exports.unmarshalJob = unmarshalJob;
exports.unmarshalJobCircuit = unmarshalJobCircuit;
exports.unmarshalListApplicationsResponse = unmarshalListApplicationsResponse;
exports.unmarshalListJobResultsResponse = unmarshalListJobResultsResponse;
exports.unmarshalListJobsResponse = unmarshalListJobsResponse;
exports.unmarshalListPlatformsResponse = unmarshalListPlatformsResponse;
exports.unmarshalListProcessResultsResponse = unmarshalListProcessResultsResponse;
exports.unmarshalListProcessesResponse = unmarshalListProcessesResponse;
exports.unmarshalListSessionACLsResponse = unmarshalListSessionACLsResponse;
exports.unmarshalListSessionsResponse = unmarshalListSessionsResponse;
exports.unmarshalPlatform = unmarshalPlatform;
exports.unmarshalProcess = unmarshalProcess;
exports.unmarshalSession = unmarshalSession;
