import { API as ParentAPI } from '../../../bridge';
import type { Region } from '../../../bridge';
import type { AddSubnetsRequest, AddSubnetsResponse, CreatePrivateNetworkRequest, CreateRouteRequest, CreateVPCRequest, DeletePrivateNetworkRequest, DeleteRouteRequest, DeleteSubnetsRequest, DeleteSubnetsResponse, DeleteVPCRequest, EnableDHCPRequest, EnableRoutingRequest, GetPrivateNetworkRequest, GetRouteRequest, GetVPCRequest, ListPrivateNetworksRequest, ListPrivateNetworksResponse, ListSubnetsRequest, ListSubnetsResponse, ListVPCsRequest, ListVPCsResponse, MigrateZonalPrivateNetworksRequest, PrivateNetwork, Route, SetSubnetsRequest, SetSubnetsResponse, UpdatePrivateNetworkRequest, UpdateRouteRequest, UpdateVPCRequest, VPC } from './types.gen';
/**
 * VPC API.
 *
 * This API allows you to manage your Virtual Private Clouds (VPCs) and Private
 * Networks.
 */
export declare class API extends ParentAPI {
    /** Lists the available regions of the API. */
    static readonly LOCALITIES: Region[];
    protected pageOfListVPCs: (request?: Readonly<ListVPCsRequest>) => Promise<ListVPCsResponse>;
    /**
     * List VPCs. List existing VPCs in the specified region.
     *
     * @param request - The request {@link ListVPCsRequest}
     * @returns A Promise of ListVPCsResponse
     */
    listVPCs: (request?: Readonly<ListVPCsRequest>) => Promise<ListVPCsResponse> & {
        all: () => Promise<VPC[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<VPC[], void, void>;
    };
    /**
     * Create a VPC. Create a new VPC in the specified region.
     *
     * @param request - The request {@link CreateVPCRequest}
     * @returns A Promise of VPC
     */
    createVPC: (request: Readonly<CreateVPCRequest>) => Promise<VPC>;
    /**
     * Get a VPC. Retrieve details of an existing VPC, specified by its VPC ID.
     *
     * @param request - The request {@link GetVPCRequest}
     * @returns A Promise of VPC
     */
    getVPC: (request: Readonly<GetVPCRequest>) => Promise<VPC>;
    /**
     * Update VPC. Update parameters including name and tags of the specified VPC.
     *
     * @param request - The request {@link UpdateVPCRequest}
     * @returns A Promise of VPC
     */
    updateVPC: (request: Readonly<UpdateVPCRequest>) => Promise<VPC>;
    /**
     * Delete a VPC. Delete a VPC specified by its VPC ID.
     *
     * @param request - The request {@link DeleteVPCRequest}
     */
    deleteVPC: (request: Readonly<DeleteVPCRequest>) => Promise<void>;
    protected pageOfListPrivateNetworks: (request?: Readonly<ListPrivateNetworksRequest>) => Promise<ListPrivateNetworksResponse>;
    /**
     * List Private Networks. List existing Private Networks in the specified
     * region. By default, the Private Networks returned in the list are ordered
     * by creation date in ascending order, though this can be modified via the
     * order_by field.
     *
     * @param request - The request {@link ListPrivateNetworksRequest}
     * @returns A Promise of ListPrivateNetworksResponse
     */
    listPrivateNetworks: (request?: Readonly<ListPrivateNetworksRequest>) => Promise<ListPrivateNetworksResponse> & {
        all: () => Promise<PrivateNetwork[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<PrivateNetwork[], void, void>;
    };
    /**
     * Create a Private Network. Create a new Private Network. Once created, you
     * can attach Scaleway resources which are in the same region.
     *
     * @param request - The request {@link CreatePrivateNetworkRequest}
     * @returns A Promise of PrivateNetwork
     */
    createPrivateNetwork: (request?: Readonly<CreatePrivateNetworkRequest>) => Promise<PrivateNetwork>;
    /**
     * Get a Private Network. Retrieve information about an existing Private
     * Network, specified by its Private Network ID. Its full details are returned
     * in the response object.
     *
     * @param request - The request {@link GetPrivateNetworkRequest}
     * @returns A Promise of PrivateNetwork
     */
    getPrivateNetwork: (request: Readonly<GetPrivateNetworkRequest>) => Promise<PrivateNetwork>;
    /**
     * Update Private Network. Update parameters (such as name or tags) of an
     * existing Private Network, specified by its Private Network ID.
     *
     * @param request - The request {@link UpdatePrivateNetworkRequest}
     * @returns A Promise of PrivateNetwork
     */
    updatePrivateNetwork: (request: Readonly<UpdatePrivateNetworkRequest>) => Promise<PrivateNetwork>;
    /**
     * Delete a Private Network. Delete an existing Private Network. Note that you
     * must first detach all resources from the network, in order to delete it.
     *
     * @param request - The request {@link DeletePrivateNetworkRequest}
     */
    deletePrivateNetwork: (request: Readonly<DeletePrivateNetworkRequest>) => Promise<void>;
    /**
     * Migrate Private Networks from zoned to regional. Transform multiple
     * existing zoned Private Networks (scoped to a single Availability Zone) into
     * regional Private Networks, scoped to an entire region. You can transform
     * one or many Private Networks (specified by their Private Network IDs)
     * within a single Scaleway Organization or Project, with the same call.
     *
     * @param request - The request {@link MigrateZonalPrivateNetworksRequest}
     */
    migrateZonalPrivateNetworks: (request?: Readonly<MigrateZonalPrivateNetworksRequest>) => Promise<void>;
    /**
     * Enable DHCP on a Private Network. Enable DHCP managed on an existing
     * Private Network. Note that you will not be able to deactivate it
     * afterwards.
     *
     * @param request - The request {@link EnableDHCPRequest}
     * @returns A Promise of PrivateNetwork
     */
    enableDHCP: (request: Readonly<EnableDHCPRequest>) => Promise<PrivateNetwork>;
    /**
     * Enable routing on a VPC. Enable routing on an existing VPC. Note that you
     * will not be able to deactivate it afterwards.
     *
     * @param request - The request {@link EnableRoutingRequest}
     * @returns A Promise of VPC
     */
    enableRouting: (request: Readonly<EnableRoutingRequest>) => Promise<VPC>;
    protected pageOfListSubnets: (request?: Readonly<ListSubnetsRequest>) => Promise<ListSubnetsResponse>;
    /**
     * List subnets. List any Private Network's subnets. See ListPrivateNetworks
     * to list a specific Private Network's subnets.
     *
     * @param request - The request {@link ListSubnetsRequest}
     * @returns A Promise of ListSubnetsResponse
     */
    listSubnets: (request?: Readonly<ListSubnetsRequest>) => Promise<ListSubnetsResponse> & {
        all: () => Promise<import("./types.gen").Subnet[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<import("./types.gen").Subnet[], void, void>;
    };
    /**
     * Set a Private Network's subnets. Set subnets for an existing Private
     * Network. Note that the method is PUT and not PATCH. Any existing subnets
     * will be removed in favor of the new specified set of subnets.
     *
     * @param request - The request {@link SetSubnetsRequest}
     * @returns A Promise of SetSubnetsResponse
     */
    setSubnets: (request: Readonly<SetSubnetsRequest>) => Promise<SetSubnetsResponse>;
    /**
     * Add subnets to a Private Network. Add new subnets to an existing Private
     * Network.
     *
     * @param request - The request {@link AddSubnetsRequest}
     * @returns A Promise of AddSubnetsResponse
     */
    addSubnets: (request: Readonly<AddSubnetsRequest>) => Promise<AddSubnetsResponse>;
    /**
     * Delete subnets from a Private Network. Delete the specified subnets from a
     * Private Network.
     *
     * @param request - The request {@link DeleteSubnetsRequest}
     * @returns A Promise of DeleteSubnetsResponse
     */
    deleteSubnets: (request: Readonly<DeleteSubnetsRequest>) => Promise<DeleteSubnetsResponse>;
    /**
     * Create a Route. Create a new custom Route.
     *
     * @param request - The request {@link CreateRouteRequest}
     * @returns A Promise of Route
     */
    createRoute: (request: Readonly<CreateRouteRequest>) => Promise<Route>;
    /**
     * Get a Route. Retrieve details of an existing Route, specified by its Route
     * ID.
     *
     * @param request - The request {@link GetRouteRequest}
     * @returns A Promise of Route
     */
    getRoute: (request: Readonly<GetRouteRequest>) => Promise<Route>;
    /**
     * Update Route. Update parameters of the specified Route.
     *
     * @param request - The request {@link UpdateRouteRequest}
     * @returns A Promise of Route
     */
    updateRoute: (request: Readonly<UpdateRouteRequest>) => Promise<Route>;
    /**
     * Delete a Route. Delete a Route specified by its Route ID.
     *
     * @param request - The request {@link DeleteRouteRequest}
     */
    deleteRoute: (request: Readonly<DeleteRouteRequest>) => Promise<void>;
}
